==> flutter_mylibrary-0.4.73.tar.gz: lib/base/getx/base_view_state_getx_controller.dart <==
import 'package:dio/dio.dart';
import 'package:flutter_mylibrary/base/request_info.dart';
import 'package:flutter_mylibrary/http/easy_dio.dart';
import 'package:flutter_mylibrary/http/exception/http_error.dart';
import 'package:flutter_mylibrary/http/http_data.dart';
import 'package:flutter_mylibrary/utils/utils.dart';
import 'package:get/get_state_manager/src/simple/get_controllers.dart';
import '../base_view_state.dart';
import 'package:get/get.dart';




///getx的页面状态基类
abstract class BaseViewStateGetxController extends GetxController with BaseViewState{


  ///页面报错信息
  ViewStateError viewStateError;

  void onError(ViewStateError viewStateError) {}


  ///--------------------------------------------设置页面状态--------------------------------------------------------------
  void setIdle() {
    viewState = ViewState.idle;
    refresh();
  }

  void setBusy() {
    viewState = ViewState.busy;
    refresh();
  }


  /// e为原始报错信息
  void setError({ViewStateErrorType errorType, e}) {

    String errorMessage;

    if(e is DioError){
      e = HttpError.dioError(e);
    }


    if(isEmpty(errorType)){
      if(e is HttpError){
        if(e.code == HttpError.CONNECT_TIMEOUT || e.code == HttpError.RECEIVE_TIMEOUT || e.code == HttpError.SEND_TIMEOUT){
          errorType = ViewStateErrorType.networkTimeOutError;
        }else{
          errorType = ViewStateErrorType.httpError;
        }
        errorMessage = e.message;
      }else{
        errorType = ViewStateErrorType.defaultError;
      }
    }

    viewState = ViewState.error;


    viewStateError = ViewStateError(
        errorType,
        error: e
    );

    onError(viewStateError);

    refresh();
  }


  ///--------------------------------------------通用请求--------------------------------------------------------------

  void request(void handleHttpData(dynamic data)) async{

    beforeRequest();

    RequestInfo requestInfo = getRequestInfo();

    getOtherData();

    HttpData _httpData = await EasyDio().request(
      requestInfo?.method,
      requestInfo?.url,
      data: requestInfo?.data,
      publicMethod: requestInfo?.publicMethod,
    );

    if(isEmpty(_httpData.httpError)){
      try{
        handleHttpData(_httpData.data);
      }catch(e){
        onError(e);
        errorType = ViewStateErrorType.jsonParsingError;
        setError(
            errorType: errorType,
            e: e
        );
      }
    }else{
      errorType = ViewStateErrorType.httpError;
      setError(
          errorType: errorType,
          e: _httpData.httpError
      );
    }
  }

}

==> flutter_mylibrary-0.4.74.tar.gz: lib/base/getx/base_view_state_getx_controller.dart <==
import 'package:dio/dio.dart';
import 'package:flutter_mylibrary/base/request_info.dart';
import 'package:flutter_mylibrary/http/easy_dio.dart';
import 'package:flutter_mylibrary/http/exception/http_error.dart';
import 'package:flutter_mylibrary/http/http_data.dart';
import 'package:flutter_mylibrary/utils/utils.dart';
import 'package:get/get_state_manager/src/simple/get_controllers.dart';
import '../base_view_state.dart';
import 'package:get/get.dart';




///getx的页面状态基类
abstract class BaseViewStateGetxController extends GetxController with BaseViewState{


  ///页面报错信息
  ViewStateError viewStateError;

  void onError(ViewStateError viewStateError) {}


  ///--------------------------------------------设置页面状态--------------------------------------------------------------
  void setIdle() {
    viewState = ViewState.idle;
    refresh();
  }

  void setBusy() {
    viewState = ViewState.busy;
    refresh();
  }


  /// e为原始报错信息
  void setError({ViewStateErrorType errorType, e, String errorMessage}) {


    if(e is DioError){
      e = HttpError.dioError(e);
    }


    if(isEmpty(errorType)){
      if(e is HttpError){
        if(e.code == HttpError.CONNECT_TIMEOUT || e.code == HttpError.RECEIVE_TIMEOUT || e.code == HttpError.SEND_TIMEOUT){
          errorType = ViewStateErrorType.networkTimeOutError;
        }else{
          errorType = ViewStateErrorType.httpError;
        }
        errorMessage = e.message;
      }else{
        errorType = ViewStateErrorType.defaultError;
      }
    }

    viewState = ViewState.error;


    viewStateError = ViewStateError(
        errorType,
        error: e
    );

    onError(viewStateError);

    refresh();
  }


  ///--------------------------------------------通用请求--------------------------------------------------------------

  void request(void handleHttpData(dynamic data)) async{

    beforeRequest();

    RequestInfo requestInfo = getRequestInfo();

    getOtherData();

    HttpData _httpData = await EasyDio().request(
      requestInfo?.method,
      requestInfo?.url,
      data: requestInfo?.data,
      publicMethod: requestInfo?.publicMethod,
    );

    if(isEmpty(_httpData.httpError)){
      try{
        handleHttpData(_httpData.data);
      }catch(e){
        onError(e);
        errorType = ViewStateErrorType.jsonParsingError;
        setError(
            errorType: errorType,
            e: e
        );
      }
    }else{
      errorType = ViewStateErrorType.httpError;
      setError(
          errorType: errorType,
          e: _httpData.httpError
      );
    }
  }

}
